==> cordial-0.1.tar.gz: cordial-0.1/setup.py <==
from setuptools import setup

setup(
  name = 'cordial',         
  packages = ['cordial'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'a low code library for content recommenders',   # Give a short description about your library
  author = 'Vagif Aliyev',                   # Type in your name
  author_email = 'vagal2003@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Vagif12/coconut',   # Provide either the link to your github or to your website
  keywords = ['machine learning', 'recommender systems', 'automation'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'numpy',
          'networkx',
          'scikit-learn'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> cordial-0.21.tar.gz: cordial-0.21/setup.py <==
from setuptools import setup

setup(
  name = 'cordial',         
  packages = ['cordial'],   # Chose the same as "name"
  version = '0.21',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'a low code library for content recommenders',   # Give a short description about your library
  author = 'Vagif Aliyev',                   # Type in your name
  author_email = 'vagal2003@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Vagif12/cordial',   # Provide either the link to your github or to your website
  keywords = ['machine learning', 'recommender systems', 'automation'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'numpy',
          'networkx',
          'scikit-learn'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
